@@ -16,6 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
  */
 
 #include <config.h>
@@ -64,6 +72,7 @@ static const GtkTargetEntry source_table[] = {
 static void vanity_action_exit (Vanity *vanity);
 
 static const struct poptOption options[] = {
+	{NULL, '\0', POPT_ARG_INCLUDE_TABLE, NULL, 0, N_("Backend options"), NULL},
 	{"debug", '\0', POPT_ARG_NONE, NULL, 0, N_("Debug mode on"), NULL},
 	{NULL, '\0', 0, NULL, 0} /* end the list */
 };
@@ -249,7 +258,7 @@ on_about1_activate (GtkButton *button, Vanity *vanity)
 
 	vanity->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
 			"name", _("Vanity"),
-			"version", VERSION,
+			"version", PACKAGE_VERSION,
 			"copyright", _("Copyright \xc2\xa9 2002-2005 Bastien Nocera"),
 			"comments", description,
 			"authors", authors,
@@ -296,7 +305,7 @@ on_save1_activate (GtkButton *button, Vanity *vanity)
 	pixbuf = bacon_video_widget_get_current_frame (vanity->bvw);
 	if (pixbuf == NULL)
 	{
-		vanity_action_error (_("Totem could not get a screenshot of that film."), _("Please file a bug, this isn't supposed to happen"), vanity);
+		vanity_action_error (_("Totem could not get a screenshot of that film."), _("This is not supposed to happen; please file a bug report."), vanity);
 		return;
 	}
 
@@ -585,8 +594,8 @@ video_widget_create (Vanity *vanity)
 
 		bacon_video_widget_play (vanity->bvw, &err);
 	} else {
-		bacon_video_widget_set_logo_mode (vanity->bvw, TRUE);
 		bacon_video_widget_set_logo (vanity->bvw, LOGO_PATH);
+		bacon_video_widget_set_logo_mode (vanity->bvw, TRUE);
 		g_message ("%s", LOGO_PATH);
 	}
 
@@ -635,7 +644,7 @@ main (int argc, char **argv)
 	if (XInitThreads () == 0)
 	{
 		gtk_init (&argc, &argv);
-		vanity_action_error_and_exit (_("Could not initialise the "
+		vanity_action_error_and_exit (_("Could not initialize the "
 					"thread-safe libraries.\n"
 					"Verify your system installation. "
 					"Vanity will now exit."), NULL);
@@ -646,12 +655,13 @@ main (int argc, char **argv)
 
 	gtk_init (&argc, &argv);
 #ifndef HAVE_GTK_ONLY
-	gnome_program_init ("vanity", VERSION,
+	gnome_program_init ("vanity", PACKAGE_VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
 			GNOME_PARAM_APP_DATADIR, DATADIR,
 			GNOME_PARAM_POPT_TABLE, options,
 			GNOME_PARAM_NONE);
+	options[0].arg = bacon_video_widget_get_popt_table ();
 #endif /* !HAVE_GTK_ONLY */
 
 	glade_init ();
@@ -660,7 +670,7 @@ main (int argc, char **argv)
 	{
 		char *str;
 
-		str = g_strdup_printf (_("Vanity couln't initialise the \n"
+		str = g_strdup_printf (_("Vanity could not initialize the \n"
 					"configuration engine:\n%s"),
 				err->message);
 		vanity_action_error_and_exit (str, NULL);
